# NudeNet: lightweight Nudity detection

```bash
pip install --upgrade nudenet
```

```python
from nudenet import NudeDetector
nude_detector = NudeDetector()
nude_detector.detect('image.jpg') # Returns list of detections
```
